@@ -4,11 +4,11 @@ use warnings;
 use vars qw/$AUTOLOAD $isROOT/;
 BEGIN {$isROOT = 1}
 
-sub AUTOLOAD {
-  $AUTOLOAD =~ s/::([^:]+)$//;
-  my $method = $1;
-  SOOT::CallMethod($AUTOLOAD, $method, \@_);
-}
+#sub AUTOLOAD {
+#  $AUTOLOAD =~ s/::([^:]+)$//;
+#  my $method = $1;
+#  SOOT::CallMethod($AUTOLOAD, $method, \@_);
+#}
 
 sub DESTROY () {}
 
